Method: Fox.fxloadTGA

Defined in:
rdoc-sources/FXTGAIcon.rb

.fxloadTGA(store) ⇒ Object

Load a Targa file from a stream. If successful, returns an array containing the image pixel data (as a String), the number of channels (either 3 or 4), the image width and the image height. If it fails, the function returns nil.

Parameters:

store

stream from which to read the file data FXStream



42
# File 'rdoc-sources/FXTGAIcon.rb', line 42

def Fox.fxloadTGA(store); end