Method: Fox.fxparseHotKey

Defined in:
rdoc-sources/fxdefs.rb

.fxparseHotKey(s) ⇒ Object

Return a hot key value that represents the hot key described in the string str. This method is less flexible than the similar Fox.fxparseAccel, and is mainly used internally for parsing the labels for FXButton and FXMenuCommand widgets. For example, this:

fxparseHotKey("&File")

returns the equivalent of:

fxparseAccel("Alt+F")


57
# File 'rdoc-sources/fxdefs.rb', line 57

def Fox.fxparseHotKey(s); end