Method: Fox::FXFont#initialize

Defined in:
rdoc-sources/FXFont.rb,
rdoc-sources/FXFont.rb,
rdoc-sources/FXFont.rb

#initialize(a, string) ⇒ FXFont

Construct a font with given font description of the form:

    fontname [ "[" foundry "]" ] ["," size ["," weight ["," slant ["," setwidth ["," encoding ["," hints]]]]]]

For example:

    "helvetica [bitstream],120,bold,italic,normal,iso8859-1,0"

Typically, at least the font name, and size must be given for
normal font matching.  As a special case, raw X11 fonts can also be
passed, for example:

    "9x15bold"

Note: use of the raw X11 fonts is stronly discouraged.



258
259
# File 'rdoc-sources/FXFont.rb', line 258

def initialize(a, fontDesc) # :yields: theFont
end