Method: Fox::FXImage#setPixels

Defined in:
rdoc-sources/FXImage.rb,
lib/fox16/core.rb

#setPixels(pix, *args) ⇒ Object

Populate the image with new pixel data of the same size or of a new size

Pixel data is copied when IMAGE_OWNED option is set or when provided as Array. Pixel data is used without copying when IMAGE_OWNED isn’t set and provided as String. In that case the string must be writable and receives modifications to the image.

If called with width and height, the size of the serverside representation of the image, if it exists, is adjusted but the contents are not updated yet. This can be done by calling render().

Parameters:

pixels

pixels [Array of FXColor values or string of raw [RGBA] values]

opts

image options [Integer]

width

image width [Integer]

height

image height [Integer]



98
99
# File 'rdoc-sources/FXImage.rb', line 98

def setPixels(pixels, opts=0, width=nil, height=nil)
end