Method: Fox::FXImage#xshear

Defined in:
rdoc-sources/FXImage.rb

#xshear(shear, color = 0) ⇒ Object

Shear image horizontally and then re-render the server-side image from the client-side pixel buffer. The number of pixels is equal to the shear parameter times 256. The area outside the image is filled with transparent black, unless another color is specified.

Parameters:

shear

how far to shear [Integer]

color

fill color for areas outside the sheared image Fox::FXColor



241
# File 'rdoc-sources/FXImage.rb', line 241

def xshear(shear, color=0); end