Method: Fox::FXMessageBox#initialize

Defined in:
rdoc-sources/FXMessageBox.rb

#initialize(owner, caption, text, ic = nil, opts = 0, x = 0, y = 0) ⇒ FXMessageBox

Construct message box with given caption, icon, and message text. If owner is a window, the message box will float over that window. If owner is the application, the message box will be free-floating.



40
41
# File 'rdoc-sources/FXMessageBox.rb', line 40

def initialize(owner, caption, text, ic=nil, opts=0, x=0, y=0) # :yields: theMessageBox
end