Class: Fox::FXPrinter
- Inherits:
-
Object
- Object
- Fox::FXPrinter
- Defined in:
- rdoc-sources/FXDCPrint.rb
Overview
Describes printer
Printer flags
PRINT_DEST_PAPERSend print to paper
PRINT_DEST_FILESend print to file
PRINT_PAGES_ALLPrint all pages
PRINT_PAGES_EVENPrint even pages only
PRINT_PAGES_ODDPrint odd pages only
PRINT_PAGES_RANGEPrint range of pages
PRINT_COLLATE_NORMALNormal collate order
PRINT_COLLATE_REVERSEDReversed collate order
PRINT_PORTRAITPortrait orientation
PRINT_LANDSCAPELandscape orientation
PRINT_BLACKANDWHITEBlack and white output
PRINT_COLORColor output
PRINT_NOBOUNDSMust determine bounding box
Printer media size
MEDIA_CUSTOMCustom paper size
MEDIA_USLETTERUS Letter size
MEDIA_LEGALUS Legal size
MEDIA_A4A4
MEDIA_ENVELOPE#10 Envelope
Instance Attribute Summary collapse
-
#bottommargin ⇒ Object
Bottom margin [Float].
-
#currentpage ⇒ Object
Current page to print [Integer].
-
#firstpage ⇒ Object
First page that can be printed [Integer].
-
#flags ⇒ Object
Flags [Integer].
-
#frompage ⇒ Object
On output, this is the first page to print [Integer].
-
#lastpage ⇒ Object
Last page that can be printed [Integer].
-
#leftmargin ⇒ Object
Left margin [Float].
-
#mediaheight ⇒ Object
Height of paper in points [Float].
-
#mediasize ⇒ Object
Media size index, one of
MEDIA_CUSTOM,MEDIA_USLETTER,MEDIA_LEGAL,MEDIA_A4orMEDIA_ENVELOPE[Integer]. -
#mediawidth ⇒ Object
Width of paper in points (1/72 of an inch) [Float].
-
#name ⇒ Object
Printer name [String].
-
#numcopies ⇒ Object
Number of copies [Integer].
-
#rightmargin ⇒ Object
Right margin [Float].
-
#topage ⇒ Object
On output, last page to print [Integer].
-
#topmargin ⇒ Object
Top margin [Float].
Instance Method Summary collapse
-
#initialize ⇒ FXPrinter
constructor
Returns an initialized FXPrinter instance.
Constructor Details
#initialize ⇒ FXPrinter
Returns an initialized FXPrinter instance
101 |
# File 'rdoc-sources/FXDCPrint.rb', line 101 def initialize; end |
Instance Attribute Details
#bottommargin ⇒ Object
Bottom margin [Float]
92 93 94 |
# File 'rdoc-sources/FXDCPrint.rb', line 92 def bottommargin @bottommargin end |
#currentpage ⇒ Object
Current page to print [Integer]
62 63 64 |
# File 'rdoc-sources/FXDCPrint.rb', line 62 def currentpage @currentpage end |
#firstpage ⇒ Object
First page that can be printed [Integer]
56 57 58 |
# File 'rdoc-sources/FXDCPrint.rb', line 56 def firstpage @firstpage end |
#flags ⇒ Object
Flags [Integer]
98 99 100 |
# File 'rdoc-sources/FXDCPrint.rb', line 98 def flags @flags end |
#frompage ⇒ Object
On output, this is the first page to print [Integer]
65 66 67 |
# File 'rdoc-sources/FXDCPrint.rb', line 65 def frompage @frompage end |
#lastpage ⇒ Object
Last page that can be printed [Integer]
59 60 61 |
# File 'rdoc-sources/FXDCPrint.rb', line 59 def lastpage @lastpage end |
#leftmargin ⇒ Object
Left margin [Float]
83 84 85 |
# File 'rdoc-sources/FXDCPrint.rb', line 83 def leftmargin @leftmargin end |
#mediaheight ⇒ Object
Height of paper in points [Float]
80 81 82 |
# File 'rdoc-sources/FXDCPrint.rb', line 80 def mediaheight @mediaheight end |
#mediasize ⇒ Object
Media size index, one of MEDIA_CUSTOM, MEDIA_USLETTER, MEDIA_LEGAL,
MEDIA_A4 or MEDIA_ENVELOPE [Integer]
74 75 76 |
# File 'rdoc-sources/FXDCPrint.rb', line 74 def mediasize @mediasize end |
#mediawidth ⇒ Object
Width of paper in points (1/72 of an inch) [Float]
77 78 79 |
# File 'rdoc-sources/FXDCPrint.rb', line 77 def mediawidth @mediawidth end |
#name ⇒ Object
Printer name [String]
53 54 55 |
# File 'rdoc-sources/FXDCPrint.rb', line 53 def name @name end |
#numcopies ⇒ Object
Number of copies [Integer]
95 96 97 |
# File 'rdoc-sources/FXDCPrint.rb', line 95 def numcopies @numcopies end |
#rightmargin ⇒ Object
Right margin [Float]
86 87 88 |
# File 'rdoc-sources/FXDCPrint.rb', line 86 def rightmargin @rightmargin end |
#topage ⇒ Object
On output, last page to print [Integer]
68 69 70 |
# File 'rdoc-sources/FXDCPrint.rb', line 68 def topage @topage end |
#topmargin ⇒ Object
Top margin [Float]
89 90 91 |
# File 'rdoc-sources/FXDCPrint.rb', line 89 def topmargin @topmargin end |