Method: Fox::FXRectangle#shrink!

Defined in:
rdoc-sources/FXRectangle.rb,
rdoc-sources/FXRectangle.rb,
rdoc-sources/FXRectangle.rb

#shrink!(leftmargin, rightmargin, topmargin, bottommargin) ⇒ Object

Shrink the rectangle by some amount, and return a reference to the rectangle.

Parameters:

leftmargin

number of units to shrink on the left side [Integer]

rightmargin

number of units to shrink on the right side [Integer]

topmargin

number of units to shrink on the top side [Integer]

bottommargin

number of units to shrink on the bottom side [Integer]



124
# File 'rdoc-sources/FXRectangle.rb', line 124

def shrink!(margin); end