Class: Fox::FXTabBar
- Inherits:
-
FXPacker
- Object
- FXObject
- FXId
- FXDrawable
- FXWindow
- FXComposite
- FXPacker
- Fox::FXTabBar
- Defined in:
- rdoc-sources/FXTabBar.rb
Overview
The FXTabBar layout manager arranges tab items side by side,
and raises the active tab item above the neighboring tab items.
In a the horizontal arrangement, the tab bar can have the tab
items on the top or on the bottom. In the vertical arrangement,
the tabs can be on the left or on the right.
When one of the tab items is pressed, the tab bar's #setCurrent()
method is called with notify of true. This in turn causes the tab bar
to send a SEL_COMMAND message to its target.
Events
The following messages are sent by FXTabBar to its target:
SEL_COMMANDsent whenever the current tab item changes; the message data is an integer indicating the new current tab item's index.
Tab book options
TABBOOK_TOPTABSTabs on top (default)
TABBOOK_BOTTOMTABSTabs on bottom
TABBOOK_SIDEWAYSTabs on left
TABBOOK_LEFTTABSTabs on left
TABBOOK_RIGHTTABSTabs on right
TABBOOK_NORMALsame as TABBOOK_TOPTABS
Message identifiers
ID_OPEN_ITEMSent from one of the FXTabItems
ID_OPEN_FIRSTSwitch to the first panel
ID_OPEN_SECONDx
ID_OPEN_THIRDx
ID_OPEN_FOURTHx
ID_OPEN_FIFTHx
ID_OPEN_SIXTHx
ID_OPEN_SEVENTHx
ID_OPEN_EIGHTHx
ID_OPEN_NINETHx
ID_OPEN_TENTHx
ID_OPEN_LASTx
Direct Known Subclasses
Instance Attribute Summary collapse
-
#current ⇒ Object
Currently active tab item's index [Integer].
-
#tabStyle ⇒ Object
Tab bar style [Integer].
Attributes inherited from FXPacker
#baseColor, #borderColor, #borderWidth, #frameStyle, #hSpacing, #hiliteColor, #packingHints, #padBottom, #padLeft, #padRight, #padTop, #shadowColor, #vSpacing
Attributes inherited from FXWindow
#accelTable, #backColor, #defaultCursor, #dragCursor, #first, #focus, #key, #last, #layoutHints, #next, #numChildren, #owner, #parent, #prev, #root, #selector, #shell, #target, #x, #y
Attributes inherited from FXDrawable
Attributes inherited from FXId
Instance Method Summary collapse
-
#initialize(p, target = nil, selector = 0, opts = TABBOOK_NORMAL, x = 0, y = 0, width = 0, height = 0, padLeft = DEFAULT_SPACING, padRight = DEFAULT_SPACING, padTop = DEFAULT_SPACING, padBottom = DEFAULT_SPACING) ⇒ FXTabBar
constructor
Return an initialized FXTabBar instance.
-
#setCurrent(index, notify = false) ⇒ Object
Change currently active tab item; this raises the active tab item slightly above the neighboring tab items.
Methods inherited from FXComposite
#maxChildHeight, #maxChildWidth
Methods inherited from FXWindow
#acceptDrop, #acquireClipboard, #acquireSelection, #active?, #addHotKey, #after?, after?, #before?, before?, #beginDrag, #canFocus?, #changeFocus, #childAtIndex, #childOf?, #children, #clearDragRectangle, #clearShape, colorType, colorTypeName, commonAncestor, #composeContext, #composite?, #contains?, #containsChild?, #create, #createComposeContext, #cursorPosition, #default?, #defaultHeight, #defaultWidth, deleteType, deleteTypeName, #destroy, #destroyComposeContext, #detach, #didAccept, #disable, #doesSaveUnder?, #dragging?, #dropDisable, #dropEnable, #dropEnabled?, #dropFinished, #dropTarget?, #each_child, #each_child_recursive, #enable, #enabled?, #endDrag, #forceRefresh, #getChildAt, #getDNDData, #getHeightForWidth, #getWidthForHeight, #grab, #grabKeyboard, #grabbed?, #grabbedKeyboard?, #handleDrag, #hasClipboard?, #hasFocus?, #hasSelection?, #height, #height=, #hide, imageType, #inFocusChain?, #indexOfChild, #initial?, #inquireDNDAction, #inquireDNDTypes, #killFocus, #layout, #linkAfter, #linkBefore, #lower, #move, octetType, octetTypeName, #offeredDNDType?, #position, #raiseWindow, #recalc, #releaseClipboard, #releaseSelection, #remHotKey, #removeChild, #repaint, #reparent, #resize, #scroll, #setCursorPosition, #setDNDData, #setDefault, #setDragRectangle, #setFocus, #setInitial, #setShape, #shell?, #show, #shown?, stringType, textType, textTypeName, #tr, #translateCoordinatesFrom, #translateCoordinatesTo, #underCursor?, #ungrab, #ungrabKeyboard, #update, urilistType, urilistTypeName, utf16Type, utf16TypeName, utf8Type, utf8TypeName, #visible=, #width, #width=
Methods included from Responder2
Methods inherited from FXDrawable
Methods inherited from FXId
#create, #created?, #destroy, #detach, #runOnUiThread
Methods inherited from FXObject
#bind, #handle, #load, #save, subclasses
Constructor Details
#initialize(p, target = nil, selector = 0, opts = TABBOOK_NORMAL, x = 0, y = 0, width = 0, height = 0, padLeft = DEFAULT_SPACING, padRight = DEFAULT_SPACING, padTop = DEFAULT_SPACING, padBottom = DEFAULT_SPACING) ⇒ FXTabBar
Return an initialized FXTabBar instance.
Parameters:
pthe parent window for this tar bar Fox::FXComposite
targetthe message target, if any, for this tar bar Fox::FXObject
selectorthe message identifier for this tab bar [Integer]
optstar bar options [Integer]
xinitial x-position [Integer]
yinitial y-position [Integer]
widthinitial width [Integer]
heightinitial height [Integer]
padLeftinternal padding on the left side, in pixels [Integer]
padRightinternal padding on the right side, in pixels [Integer]
padTopinternal padding on the top side, in pixels [Integer]
padBottominternal padding on the bottom side, in pixels [Integer]
69 70 |
# File 'rdoc-sources/FXTabBar.rb', line 69 def initialize(p, target=nil, selector=0, opts=TABBOOK_NORMAL, x=0, y=0, width=0, height=0, padLeft=DEFAULT_SPACING, padRight=DEFAULT_SPACING, padTop=DEFAULT_SPACING, padBottom=DEFAULT_SPACING) # :yields: theTabBar end |
Instance Attribute Details
#current ⇒ Object
Currently active tab item's index [Integer]
46 47 48 |
# File 'rdoc-sources/FXTabBar.rb', line 46 def current @current end |
#tabStyle ⇒ Object
Tab bar style [Integer]
49 50 51 |
# File 'rdoc-sources/FXTabBar.rb', line 49 def tabStyle @tabStyle end |
Instance Method Details
#setCurrent(index, notify = false) ⇒ Object
Change currently active tab item; this raises the active tab item
slightly above the neighboring tab items.
If notify is true, a SEL_COMMAND message is sent to the tab bar's message target
77 |
# File 'rdoc-sources/FXTabBar.rb', line 77 def setCurrent(index, notify=false); end |