Method: Fox::FXToggleButton#initialize

Defined in:
rdoc-sources/FXToggleButton.rb

#initialize(p, text1, text2, icon1 = nil, icon2 = nil, target = nil, selector = 0, opts = TOGGLEBUTTON_NORMAL, x = 0, y = 0, width = 0, height = 0, padLeft = DEFAULT_PAD, padRight = DEFAULT_PAD, padTop = DEFAULT_PAD, padBottom = DEFAULT_PAD) ⇒ FXToggleButton

Return an initialized FXToggleButton instance.

Parameters:

p

the parent window for this toggle button Fox::FXComposite

text1

the text for this toggle button’s first state [String]

text2

the text for this toggle button’s second state [String]

icon1

the icon, if any, for this toggle button’s first state Fox::FXIcon

icon2

the icon, if any, for this toggle button’s second state Fox::FXIcon

target

the message target, if any, for this toggle button Fox::FXObject

selector

the message identifier for this toggle button [Integer]

opts

toggle button options [Integer]

x

initial x-position [Integer]

y

initial y-position [Integer]

width

initial width [Integer]

height

initial height [Integer]

padLeft

internal padding on the left side, in pixels [Integer]

padRight

internal padding on the right side, in pixels [Integer]

padTop

internal padding on the top side, in pixels [Integer]

padBottom

internal padding on the bottom side, in pixels [Integer]



67
68
# File 'rdoc-sources/FXToggleButton.rb', line 67

def initialize(p, text1, text2, icon1=nil, icon2=nil, target=nil, selector=0, opts=TOGGLEBUTTON_NORMAL, x=0, y=0, width=0, height=0, padLeft=DEFAULT_PAD, padRight=DEFAULT_PAD, padTop=DEFAULT_PAD, padBottom=DEFAULT_PAD) # :yields: theToggleButton
end