Class: Fox::FXToolBar
- Inherits:
-
FXDockBar
- Object
- FXObject
- FXId
- FXDrawable
- FXWindow
- FXComposite
- FXPacker
- FXDockBar
- Fox::FXToolBar
- Defined in:
- rdoc-sources/FXToolBar.rb
Overview
A tool bar widget can be docked in a dock site; it automatically adjusts its orientation based on the orientation of the dock site, and adjusts the layout options accordingly. See FXDockBar widget for more information on the docking behavior.
Direct Known Subclasses
Instance Attribute Summary collapse
-
#dockingSide ⇒ Object
Docking side, one of
LAYOUT_SIDE_LEFT,LAYOUT_SIDE_RIGHT,LAYOUT_SIDE_TOPorLAYOUT_SIDE_BOTTOM[Integer].
Attributes inherited from FXPacker
#baseColor, #borderColor, #borderWidth, #frameStyle, #hSpacing, #hiliteColor, #packingHints, #padBottom, #padLeft, #padRight, #padTop, #shadowColor, #vSpacing
Attributes inherited from FXWindow
#accelTable, #backColor, #defaultCursor, #dragCursor, #first, #focus, #key, #last, #layoutHints, #next, #numChildren, #owner, #parent, #prev, #root, #selector, #shell, #target, #x, #y
Attributes inherited from FXDrawable
Attributes inherited from FXId
Instance Method Summary collapse
-
#initialize(p, opts = LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X, x = 0, y = 0, width = 0, height = 0, padLeft = 3, padRight = 3, padTop = 2, padBottom = 2, hSpacing = DEFAULT_SPACING, vSpacing = DEFAULT_SPACING) ⇒ FXToolBar
constructor
Return an initialized, stationary FXToolBar instance.
Methods inherited from FXDockBar
#allowSide, #allowedSide?, #allowedSides, #allowedSides=, #disallowSide, #dock, #docked?, #dryDock, #dryDock=, #findDockAtSide, #findDockNear, #insideDock?, #undock, #wetDock, #wetDock=
Methods inherited from FXComposite
#maxChildHeight, #maxChildWidth
Methods inherited from FXWindow
#acceptDrop, #acquireClipboard, #acquireSelection, #active?, #addHotKey, #after?, after?, #before?, before?, #beginDrag, #canFocus?, #changeFocus, #childAtIndex, #childOf?, #children, #clearDragRectangle, #clearShape, colorType, colorTypeName, commonAncestor, #composeContext, #composite?, #contains?, #containsChild?, #create, #createComposeContext, #cursorPosition, #default?, #defaultHeight, #defaultWidth, deleteType, deleteTypeName, #destroy, #destroyComposeContext, #detach, #didAccept, #disable, #doesSaveUnder?, #dragging?, #dropDisable, #dropEnable, #dropEnabled?, #dropFinished, #dropTarget?, #each_child, #each_child_recursive, #enable, #enabled?, #endDrag, #forceRefresh, #getChildAt, #getDNDData, #getHeightForWidth, #getWidthForHeight, #grab, #grabKeyboard, #grabbed?, #grabbedKeyboard?, #handleDrag, #hasClipboard?, #hasFocus?, #hasSelection?, #height, #height=, #hide, imageType, #inFocusChain?, #indexOfChild, #initial?, #inquireDNDAction, #inquireDNDTypes, #killFocus, #layout, #linkAfter, #linkBefore, #lower, #move, octetType, octetTypeName, #offeredDNDType?, #position, #raiseWindow, #recalc, #releaseClipboard, #releaseSelection, #remHotKey, #removeChild, #repaint, #reparent, #resize, #scroll, #setCursorPosition, #setDNDData, #setDefault, #setDragRectangle, #setFocus, #setInitial, #setShape, #shell?, #show, #shown?, stringType, textType, textTypeName, #tr, #translateCoordinatesFrom, #translateCoordinatesTo, #underCursor?, #ungrab, #ungrabKeyboard, #update, urilistType, urilistTypeName, utf16Type, utf16TypeName, utf8Type, utf8TypeName, #visible=, #width, #width=
Methods included from Responder2
Methods inherited from FXDrawable
Methods inherited from FXId
#create, #created?, #destroy, #detach, #runOnUiThread
Methods inherited from FXObject
#bind, #handle, #load, #save, subclasses
Constructor Details
#initialize(p, opts = LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X, x = 0, y = 0, width = 0, height = 0, padLeft = 3, padRight = 3, padTop = 2, padBottom = 2, hSpacing = DEFAULT_SPACING, vSpacing = DEFAULT_SPACING) ⇒ FXToolBar
Return an initialized, stationary FXToolBar instance. The tool bar can not be undocked.
Parameters:
pthe parent window for this tool bar Fox::FXComposite
optstool bar options [Integer]
xinitial x-position [Integer]
yinitial y-position [Integer]
widthinitial width [Integer]
heightinitial height [Integer]
padLeftinternal padding on the left side, in pixels [Integer]
padRightinternal padding on the right side, in pixels [Integer]
padTopinternal padding on the top side, in pixels [Integer]
padBottominternal padding on the bottom side, in pixels [Integer]
hSpacinghorizontal spacing between widgets, in pixels [Integer]
vSpacingvertical spacing between widgets, in pixels [Integer]
35 36 |
# File 'rdoc-sources/FXToolBar.rb', line 35 def initialize(p, q, opts=LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X, x=0, y=0, width=0, height=0, padLeft=3, padRight=3, padTop=2, padBottom=2, hSpacing=DEFAULT_SPACING, vSpacing=DEFAULT_SPACING) # :yields: theToolBar end |
Instance Attribute Details
#dockingSide ⇒ Object
Docking side, one of LAYOUT_SIDE_LEFT, LAYOUT_SIDE_RIGHT, LAYOUT_SIDE_TOP or LAYOUT_SIDE_BOTTOM [Integer]
11 12 13 |
# File 'rdoc-sources/FXToolBar.rb', line 11 def dockingSide @dockingSide end |