Method: Fox::FXTreeList#prependItem

Defined in:
rdoc-sources/FXTreeList.rb,
rdoc-sources/FXTreeList.rb

#prependItem(father, text, oi = nil, ci = nil, ptr = nil, notify = false) ⇒ Object

Prepend item with given text and optional icons, and user-data pointer as first child of father. Returns a reference to the newly added item (an FXTreeItem instance). If notify is true, a SEL_INSERTED message is sent to the list’s message target after the item is added.



309
# File 'rdoc-sources/FXTreeList.rb', line 309

def prependItem(father, item, notify=false); end