Method: Fox::FXScintilla#getCurLine
- Defined in:
- lib/fox16/scintilla.rb
#getCurLine(length) ⇒ Object
Retrieve the text of the line containing the caret. Returns the index of the caret on the line.
175 176 177 178 179 |
# File 'lib/fox16/scintilla.rb', line 175 def getCurLine(length) buffer = "".ljust(length) sendMessage(2027, length, buffer) buffer end |