Method: Fox::FXChoiceBox#initialize
- Defined in:
- rdoc-sources/FXChoiceBox.rb
#initialize(owner, caption, text, icon, choices, opts = 0, x = 0, y = 0, width = 0, height = 0) ⇒ FXChoiceBox
Construct choice box with given caption, icon, message text, and with choices from array of strings. If owner is another FXWindow, the dialog box is created as a child of that window. If owner is an FXApp instance, it’s created as a free-floating dialog box.
Parameters:
owner-
Owner for this dialog box [FXWindow or FXApp]
caption-
Caption for this dialog box [String]
text-
Message text for this dialog box [String]
icon-
Icon for this dialog box Fox::FXIcon
choices-
Array of strings containing choices [Array]
opts-
Dialog box options [Integer]
x-
x-coordinate
y-
y-coordinate
width-
width
height-
height
27 28 |
# File 'rdoc-sources/FXChoiceBox.rb', line 27 def initialize(owner, caption, text, icon, choices, opts=0, x=0, y=0, width=0, height=0) # :yields: theChoiceBox end |