Class: Fox::FXFileSelector
- Inherits:
-
FXPacker
- Object
- FXObject
- FXId
- FXDrawable
- FXWindow
- FXComposite
- FXPacker
- Fox::FXFileSelector
- Defined in:
- rdoc-sources/FXFileSelector.rb,
lib/fox16/core.rb
Overview
File selection widget
File selection modes
SELECTFILE_ANYA single file, existing or not (to save to)
SELECTFILE_EXISTINGAn existing file (to load)
SELECTFILE_MULTIPLEMultiple existing files
SELECTFILE_MULTIPLE_ALLMultiple existing files or directories, but not '.' and '..'
SELECTFILE_DIRECTORYExisting directory, including '.' or '..'
Wildcard matching modes
FILEMATCH_FILE_NAMENo wildcard can ever match "/" (or "","/" under Windows).
FILEMATCH_NOESCAPEBackslashes don't quote special chars ("" is treated as "").
FILEMATCH_PERIODLeading "." is matched only explicitly (Useful to match hidden files on Unix).
FILEMATCH_LEADING_DIRIgnore "/..." after a match.
FILEMATCH_CASEFOLDCompare without regard to case.
Note that under Windows, FILEMATCH_NOESCAPE must be passed.
Message identifiers
ID_FILEFILTERx
ID_ACCEPTx
ID_FILELISTx
ID_DIRECTORY_UPx
ID_DIRTREEx
ID_NORMAL_SIZEx
ID_MEDIUM_SIZEx
ID_GIANT_SIZEx
ID_HOMEx
ID_WORKx
ID_BOOKMARKx
ID_BOOKMENUx
ID_VISITx
ID_NEWx
ID_DELETEx
ID_MOVEx
ID_COPYx
ID_LINKx
Instance Attribute Summary collapse
-
#acceptButton ⇒ Object
readonly
The "Accept" button FXButton.
-
#cancelButton ⇒ Object
readonly
The "Cancel" button FXButton.
-
#currentPattern ⇒ Object
Current pattern number [Integer].
-
#directory ⇒ Object
Directory [String].
-
#fileBoxStyle ⇒ Object
Change file list style [Integer].
-
#filename ⇒ Object
File name [String].
-
#imageSize ⇒ Object
Image size for preview images [Integer].
-
#itemSpace ⇒ Object
Inter-item spacing (in pixels) [Integer].
-
#matchMode ⇒ Object
Wildcard matching mode [Integer].
-
#pattern ⇒ Object
File pattern [String].
-
#selectMode ⇒ Object
Change file selection mode [Integer].
Attributes inherited from FXPacker
#baseColor, #borderColor, #borderWidth, #frameStyle, #hSpacing, #hiliteColor, #packingHints, #padBottom, #padLeft, #padRight, #padTop, #shadowColor, #vSpacing
Attributes inherited from FXWindow
#accelTable, #backColor, #defaultCursor, #dragCursor, #first, #focus, #key, #last, #layoutHints, #next, #numChildren, #owner, #parent, #prev, #root, #selector, #shell, #target, #x, #y
Attributes inherited from FXDrawable
Attributes inherited from FXId
Class Method Summary collapse
-
.extensionFromPattern(pattern) ⇒ Object
Given a pattern of the form ".gif,.GIF", return the first extension of the pattern, i.e.
-
.patternFromText(pattern) ⇒ Object
Given filename pattern of the form "GIF Format (*.gif)", returns the pattern only, i.e.
Instance Method Summary collapse
-
#allowNavigation ⇒ Object
Allow navigation for this file selector.
-
#disallowNavigation ⇒ Object
Disallow navigation for this file selector.
-
#filenames ⇒ Object
Returns an array of the selected file names.
-
#getPatternList ⇒ Object
Returns the list of patterns (an Array of Strings).
-
#getPatternText(patno) ⇒ Object
Get pattern text for given pattern number.
-
#hiddenFilesShown=(state) ⇒ Object
If state is
true, the file selector will show hidden files and directories; otherwise, it won't. -
#hiddenFilesShown? ⇒ Boolean
Return
trueif showing hidden files and directories. -
#imagesShown=(shown) ⇒ Object
If shown is
true, the file selector will show preview images; otherwise it won't. -
#imagesShown? ⇒ Boolean
Return
trueif the file selector is showing preview images. -
#initialize(p, target = nil, selector = 0, opts = 0, x = 0, y = 0, width = 0, height = 0) ⇒ FXFileSelector
constructor
Return an initialized FXFileSelector instance.
-
#navigationAllowed=(allowed) ⇒ Object
Set navigation to allowed (+true+) or disallowed (+false+).
-
#navigationAllowed? ⇒ Boolean
Return
trueif navigation allowed. -
#numPatterns ⇒ Object
Return number of patterns.
-
#readOnly=(state) ⇒ Object
Set state of read-only button.
-
#readOnly? ⇒ Boolean
Return
trueif in read-only mode. -
#readOnlyShown=(shown) ⇒ Object
Show read-only button.
-
#readOnlyShown? ⇒ Boolean
Return
trueif the read-only button is shown. -
#setPatternList(patterns) ⇒ Object
Change the list of file patterns shown in the file selector.
-
#setPatternText(patno, text) ⇒ Object
Change pattern text for pattern number.
Methods inherited from FXComposite
#maxChildHeight, #maxChildWidth
Methods inherited from FXWindow
#acceptDrop, #acquireClipboard, #acquireSelection, #active?, #addHotKey, #after?, after?, #before?, before?, #beginDrag, #canFocus?, #changeFocus, #childAtIndex, #childOf?, #children, #clearDragRectangle, #clearShape, colorType, colorTypeName, commonAncestor, #composeContext, #composite?, #contains?, #containsChild?, #create, #createComposeContext, #cursorPosition, #default?, #defaultHeight, #defaultWidth, deleteType, deleteTypeName, #destroy, #destroyComposeContext, #detach, #didAccept, #disable, #doesSaveUnder?, #dragging?, #dropDisable, #dropEnable, #dropEnabled?, #dropFinished, #dropTarget?, #each_child, #each_child_recursive, #enable, #enabled?, #endDrag, #forceRefresh, #getChildAt, #getDNDData, #getHeightForWidth, #getWidthForHeight, #grab, #grabKeyboard, #grabbed?, #grabbedKeyboard?, #handleDrag, #hasClipboard?, #hasFocus?, #hasSelection?, #height, #height=, #hide, imageType, #inFocusChain?, #indexOfChild, #initial?, #inquireDNDAction, #inquireDNDTypes, #killFocus, #layout, #linkAfter, #linkBefore, #lower, #move, octetType, octetTypeName, #offeredDNDType?, #position, #raiseWindow, #recalc, #releaseClipboard, #releaseSelection, #remHotKey, #removeChild, #repaint, #reparent, #resize, #scroll, #setCursorPosition, #setDNDData, #setDefault, #setDragRectangle, #setFocus, #setInitial, #setShape, #shell?, #show, #shown?, stringType, textType, textTypeName, #tr, #translateCoordinatesFrom, #translateCoordinatesTo, #underCursor?, #ungrab, #ungrabKeyboard, #update, urilistType, urilistTypeName, utf16Type, utf16TypeName, utf8Type, utf8TypeName, #visible=, #width, #width=
Methods included from Responder2
Methods inherited from FXDrawable
Methods inherited from FXId
#create, #created?, #destroy, #detach, #runOnUiThread
Methods inherited from FXObject
#bind, #handle, #load, #save, subclasses
Constructor Details
#initialize(p, target = nil, selector = 0, opts = 0, x = 0, y = 0, width = 0, height = 0) ⇒ FXFileSelector
Return an initialized FXFileSelector instance.
82 83 |
# File 'rdoc-sources/FXFileSelector.rb', line 82 def initialize(p, target=nil, selector=0, opts=0, x=0, y=0, width=0, height=0) # :yields: theFileSelector end |
Instance Attribute Details
#acceptButton ⇒ Object (readonly)
The "Accept" button Fox::FXButton
47 48 49 |
# File 'rdoc-sources/FXFileSelector.rb', line 47 def acceptButton @acceptButton end |
#cancelButton ⇒ Object (readonly)
The "Cancel" button Fox::FXButton
50 51 52 |
# File 'rdoc-sources/FXFileSelector.rb', line 50 def cancelButton @cancelButton end |
#currentPattern ⇒ Object
Current pattern number [Integer]
62 63 64 |
# File 'rdoc-sources/FXFileSelector.rb', line 62 def currentPattern @currentPattern end |
#directory ⇒ Object
Directory [String]
59 60 61 |
# File 'rdoc-sources/FXFileSelector.rb', line 59 def directory @directory end |
#fileBoxStyle ⇒ Object
Change file list style [Integer]
68 69 70 |
# File 'rdoc-sources/FXFileSelector.rb', line 68 def fileBoxStyle @fileBoxStyle end |
#filename ⇒ Object
File name [String]
53 54 55 |
# File 'rdoc-sources/FXFileSelector.rb', line 53 def filename @filename end |
#imageSize ⇒ Object
Image size for preview images [Integer]
77 78 79 |
# File 'rdoc-sources/FXFileSelector.rb', line 77 def imageSize @imageSize end |
#itemSpace ⇒ Object
Inter-item spacing (in pixels) [Integer]
65 66 67 |
# File 'rdoc-sources/FXFileSelector.rb', line 65 def itemSpace @itemSpace end |
#matchMode ⇒ Object
Wildcard matching mode [Integer]
74 75 76 |
# File 'rdoc-sources/FXFileSelector.rb', line 74 def matchMode @matchMode end |
#pattern ⇒ Object
File pattern [String]
56 57 58 |
# File 'rdoc-sources/FXFileSelector.rb', line 56 def pattern @pattern end |
#selectMode ⇒ Object
Change file selection mode [Integer]
71 72 73 |
# File 'rdoc-sources/FXFileSelector.rb', line 71 def selectMode @selectMode end |
Class Method Details
.extensionFromPattern(pattern) ⇒ Object
Given a pattern of the form ".gif,.GIF", return the first extension of the pattern, i.e. "gif" in this example. Returns empty string if it doesn't work out.
181 |
# File 'rdoc-sources/FXFileSelector.rb', line 181 def FXFileSelector.extensionFromPattern(pattern) ; end |
.patternFromText(pattern) ⇒ Object
Given filename pattern of the form "GIF Format (.gif)", returns the pattern only, i.e. ".gif" in this case. If the parentheses are not found then returns the entire input pattern.
174 |
# File 'rdoc-sources/FXFileSelector.rb', line 174 def FXFileSelector.patternFromText(pattern) ; end |
Instance Method Details
#allowNavigation ⇒ Object
Allow navigation for this file selector
138 139 140 |
# File 'lib/fox16/core.rb', line 138 def self. = true end |
#disallowNavigation ⇒ Object
Disallow navigation for this file selector
143 144 145 |
# File 'lib/fox16/core.rb', line 143 def self. = false end |
#filenames ⇒ Object
Returns an array of the selected file names.
88 |
# File 'rdoc-sources/FXFileSelector.rb', line 88 def filenames; end |
#getPatternList ⇒ Object
Returns the list of patterns (an Array of Strings).
119 |
# File 'rdoc-sources/FXFileSelector.rb', line 119 def getPatternList(); end |
#getPatternText(patno) ⇒ Object
Get pattern text for given pattern number
122 |
# File 'rdoc-sources/FXFileSelector.rb', line 122 def getPatternText(patno); end |
#hiddenFilesShown=(state) ⇒ Object
If state is true, the file selector will show hidden files and
directories; otherwise, it won't.
149 |
# File 'rdoc-sources/FXFileSelector.rb', line 149 def hiddenFilesShown=(state); end |
#hiddenFilesShown? ⇒ Boolean
Return true if showing hidden files and directories
143 |
# File 'rdoc-sources/FXFileSelector.rb', line 143 def hiddenFilesShown?; end |
#imagesShown=(shown) ⇒ Object
If shown is true, the file selector will show preview images;
otherwise it won't.
155 |
# File 'rdoc-sources/FXFileSelector.rb', line 155 def imagesShown=(shown); end |
#imagesShown? ⇒ Boolean
Return true if the file selector is showing preview images.
160 |
# File 'rdoc-sources/FXFileSelector.rb', line 160 def imagesShown? ; end |
#navigationAllowed=(allowed) ⇒ Object
Set navigation to allowed (+true+) or disallowed (+false+)
166 |
# File 'rdoc-sources/FXFileSelector.rb', line 166 def (allowed); end |
#navigationAllowed? ⇒ Boolean
Return true if navigation allowed.
163 |
# File 'rdoc-sources/FXFileSelector.rb', line 163 def ; end |
#numPatterns ⇒ Object
Return number of patterns.
128 |
# File 'rdoc-sources/FXFileSelector.rb', line 128 def numPatterns; end |
#readOnly=(state) ⇒ Object
Set state of read-only button.
137 |
# File 'rdoc-sources/FXFileSelector.rb', line 137 def readOnly=(state); end |
#readOnly? ⇒ Boolean
Return true if in read-only mode.
140 |
# File 'rdoc-sources/FXFileSelector.rb', line 140 def readOnly?; end |
#readOnlyShown=(shown) ⇒ Object
Show read-only button.
131 |
# File 'rdoc-sources/FXFileSelector.rb', line 131 def readOnlyShown=(shown); end |
#readOnlyShown? ⇒ Boolean
Return true if the read-only button is shown.
134 |
# File 'rdoc-sources/FXFileSelector.rb', line 134 def readOnlyShown?; end |
#setPatternList(patterns) ⇒ Object
Change the list of file patterns shown in the file selector. The patterns argument is an array of strings, and each string represents a different file pattern. A pattern consists of an optional name, followed by a pattern in parentheses. For example, this code:
patterns = [ "*", "*.cpp,*.cc", "*.hpp,*.hh,*.h" ]
aFileSelector.setPatternList(patterns)
and this code:
patterns = [ "All Files (*)", "C++ Sources (*.cpp,*.cc)", "C++ Headers (*.hpp,*.hh,*.h)" ]
aFileSelector.setPatternList(patterns)
will both set the same three patterns, but the former shows no pattern names.
For compatibility with the FOX C++ library API of the same name, #setPatternList also accepts a patterns value that is a single string, with each pattern separated by newline characters, e.g.
patterns = "All Files (*)\nC++ Sources (*.cpp,*.cc)\nC++ Headers (*.hpp,*.hh,*.h)"
aFileSelector.setPatternList(patterns)
114 |
# File 'rdoc-sources/FXFileSelector.rb', line 114 def setPatternList(patterns); end |
#setPatternText(patno, text) ⇒ Object
Change pattern text for pattern number
125 |
# File 'rdoc-sources/FXFileSelector.rb', line 125 def setPatternText(patno, text); end |