Method: Fox::FXHeader#prependItem
- Defined in:
-
rdoc-sources/FXHeader.rb,
rdoc-sources/FXHeader.rb
Prepend a new item with the specified text, icon, size and user data object, and return the index of the appended item. If notify is true, a SEL_INSERTED message is sent to the header’s message target after the item is appended.
246 |
# File 'rdoc-sources/FXHeader.rb', line 246 def prependItem(item, notify=false); end |