Method: Fox::FXImage#dataPtr
- Defined in:
- rdoc-sources/FXImage.rb
#dataPtr ⇒ Object (readonly)
The pointer to the raw color representation of all image pixels.
It can be used to pass raw image data to FFI, Fiddle or OpenGL.
51 52 53 |
# File 'rdoc-sources/FXImage.rb', line 51 def dataPtr @dataPtr end |