Method: Fox::FXImage#mirror
- Defined in:
- rdoc-sources/FXImage.rb
#mirror(horizontal, vertical) ⇒ Object
Mirror image horizontally and/or vertically and then re-render the server-side image from the client-side pixel buffer.
Parameters:
horizontal-
if
true, the image will be flipped from left to right [Boolean] vertical-
if
true, the image will be flipped from top to bottom [Boolean]
186 |
# File 'rdoc-sources/FXImage.rb', line 186 def mirror(horizontal, vertical) ; end |