Method: Fox::FXRectangle#shrink!
- Defined in:
-
rdoc-sources/FXRectangle.rb,
rdoc-sources/FXRectangle.rb,
rdoc-sources/FXRectangle.rb
Shrink the rectangle by some amount, and return a reference to the rectangle.
leftmarginnumber of units to shrink on the left side [Integer]
rightmarginnumber of units to shrink on the right side [Integer]
topmarginnumber of units to shrink on the top side [Integer]
bottommarginnumber of units to shrink on the bottom side [Integer]
124 |
# File 'rdoc-sources/FXRectangle.rb', line 124 def shrink!(margin); end |