Method: Fox::FXShutter#initialize
- Defined in:
- rdoc-sources/FXShutter.rb
#initialize(p, target = nil, selector = 0, opts = 0, x = 0, y = 0, width = 0, height = 0, padLeft = DEFAULT_SPACING, padRight = DEFAULT_SPACING, padTop = DEFAULT_SPACING, padBottom = DEFAULT_SPACING, hSpacing = DEFAULT_SPACING, vSpacing = DEFAULT_SPACING) ⇒ FXShutter
Return an initialized FXShutter instance.
Parameters:
p-
the parent window for this shutter Fox::FXComposite
target-
the message target, if any, for this shutter Fox::FXObject
selector-
the message identifier for this shutter [Integer]
opts-
shutter options [Integer]
x-
initial x-position [Integer]
y-
initial y-position [Integer]
width-
initial width [Integer]
height-
initial height [Integer]
padLeft-
internal padding on the left side, in pixels [Integer]
padRight-
internal padding on the right side, in pixels [Integer]
padTop-
internal padding on the top side, in pixels [Integer]
padBottom-
internal padding on the bottom side, in pixels [Integer]
hSpacing-
horizontal spacing between widgets, in pixels [Integer]
vSpacing-
vertical spacing between widgets, in pixels [Integer]
98 99 |
# File 'rdoc-sources/FXShutter.rb', line 98 def initialize(p, target=nil, selector=0, opts=0, x=0, y=0, width=0, height=0, padLeft=DEFAULT_SPACING, padRight=DEFAULT_SPACING, padTop=DEFAULT_SPACING, padBottom=DEFAULT_SPACING, hSpacing=DEFAULT_SPACING, vSpacing=DEFAULT_SPACING) # :yields: theShutter end |