Method: Fox::FXTable#removeRange
- Defined in:
- rdoc-sources/FXTable.rb
#removeRange(startrow, endrow, startcol, endcol, notify = false) ⇒ Object
Remove all cells in the specified range of rows and columns. If notify is true, a SEL_REPLACED message is sent to the table’s message target before each cell is removed. Raises IndexError if startrow, endrow, startcol or endcol is out of bounds.
578 |
# File 'rdoc-sources/FXTable.rb', line 578 def removeRange(startrow, endrow, startcol, endcol, notify=false); end |